package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DictTypeMapper;
import com.zyc.system.domain.DictType;
import com.zyc.system.service.IDictTypeService;

/**
 * 字典类型Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DictTypeServiceImpl implements IDictTypeService 
{
    @Autowired
    private DictTypeMapper dictTypeMapper;

    /**
     * 查询字典类型
     * 
     * @param id 字典类型主键
     * @return 字典类型
     */
    @Override
    public DictType selectDictTypeById(Integer id)
    {
        return dictTypeMapper.selectDictTypeById(id);
    }

    /**
     * 查询字典类型列表
     * 
     * @param dictType 字典类型
     * @return 字典类型
     */
    @Override
    public List<DictType> selectDictTypeList(DictType dictType)
    {
        return dictTypeMapper.selectDictTypeList(dictType);
    }

    /**
     * 新增字典类型
     * 
     * @param dictType 字典类型
     * @return 结果
     */
    @Override
    public int insertDictType(DictType dictType)
    {
        return dictTypeMapper.insertDictType(dictType);
    }

    /**
     * 修改字典类型
     * 
     * @param dictType 字典类型
     * @return 结果
     */
    @Override
    public int updateDictType(DictType dictType)
    {
        return dictTypeMapper.updateDictType(dictType);
    }

    /**
     * 批量删除字典类型
     * 
     * @param ids 需要删除的字典类型主键
     * @return 结果
     */
    @Override
    public int deleteDictTypeByIds(Integer[] ids)
    {
        return dictTypeMapper.deleteDictTypeByIds(ids);
    }

    /**
     * 删除字典类型信息
     * 
     * @param id 字典类型主键
     * @return 结果
     */
    @Override
    public int deleteDictTypeById(Integer id)
    {
        return dictTypeMapper.deleteDictTypeById(id);
    }
}
